==> haskell-wuss-2.0.1.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wuss
version:              2.0.1.1
visibility:           public
id:                   wuss-2.0.1.1-CxybV9VrncHBfIxwxCIu4U
key:                  wuss-2.0.1.1-CxybV9VrncHBfIxwxCIu4U
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  6111a5e1a5382d8457f07740f582d04c
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wuss-2.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wuss-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.1-CxybV9VrncHBfIxwxCIu4U
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    crypton-connection-0.3.2-LMncCDQhd4i4TgBjqBJCnu exceptions-0.10.4
    network-3.1.4.0-Hw2M7QXfBbV5zvwWyCqJAC
    websockets-0.12.7.3-LKKWLbZ52TZDJAgZLNtW3H

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wuss-2.0.1.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wuss
version:              2.0.1.1
visibility:           public
id:                   wuss-2.0.1.1-CN8x4uySHWsnqAkz8QRmJ
key:                  wuss-2.0.1.1-CN8x4uySHWsnqAkz8QRmJ
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  072d91f60b94a008e493546676e646e8
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wuss-2.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wuss-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.1-CN8x4uySHWsnqAkz8QRmJ
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    crypton-connection-0.3.2-DxHeLSsI363G69t6facGAF exceptions-0.10.4
    network-3.1.4.0-IMH4i2bhORraAL0d8HxBg
    websockets-0.12.7.3-1ICYtODDLcUEpknRQUi4Fz

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
